@@ -43,6 +43,13 @@ impl Symbol {
             .into_iter()
             .find(|filter| matches!(filter, Filters::LotSize { .. }))
     }
+
+    pub fn market_lot_size(&self) -> Option<Filters> {
+        self.filters
+            .clone()
+            .into_iter()
+            .find(|filter| matches!(filter, Filters::MarketLotSize { .. }))
+    }
 }
 
 #[derive(Debug, Serialize, Deserialize, Clone)]
@@ -77,6 +84,16 @@ pub enum Filters {
         #[serde(with = "string_or_float")]
         step_size: f64,
     },
+    #[serde(rename = "MARKET_LOT_SIZE")]
+    #[serde(rename_all = "camelCase")]
+    MarketLotSize {
+        #[serde(with = "string_or_float")]
+        min_qty: f64,
+        #[serde(with = "string_or_float")]
+        max_qty: f64,
+        #[serde(with = "string_or_float")]
+        step_size: f64,
+    },
     #[serde(rename = "MIN_NOTIONAL")]
     #[serde(rename_all = "camelCase")]
     MinNotional {
@@ -88,13 +105,6 @@ pub enum Filters {
     #[serde(rename = "ICEBERG_PARTS")]
     #[serde(rename_all = "camelCase")]
     IcebergParts { limit: u16 },
-    #[serde(rename = "MARKET_LOT_SIZE")]
-    #[serde(rename_all = "camelCase")]
-    MarketLotSize {
-        min_qty: String,
-        max_qty: String,
-        step_size: String,
-    },
     #[serde(rename = "MAX_NUM_ORDERS")]
     #[serde(rename_all = "camelCase")]
     MaxNumOrders { max_num_orders: u16 },
@@ -160,8 +170,10 @@ pub enum AccountType {
 #[serde(rename_all = "camelCase")]
 pub struct Balance {
     pub asset: String,
-    pub free: String,
-    pub locked: String,
+    #[serde(with = "string_or_float")]
+    pub free: f64,
+    #[serde(with = "string_or_float")]
+    pub locked: f64,
 }
 
 #[derive(Debug, Serialize, Deserialize, Clone)]
@@ -378,6 +390,26 @@ pub struct PriceStats {
     pub count: u64,
 }
 
+#[derive(Debug, Serialize, Deserialize, Clone)]
+pub struct AggTrade {
+    #[serde(rename = "T")]
+    pub time: u64,
+    #[serde(rename = "a")]
+    pub agg_id: u64,
+    #[serde(rename = "f")]
+    pub first_id: u64,
+    #[serde(rename = "l")]
+    pub last_id: u64,
+    #[serde(rename = "m")]
+    pub maker: bool,
+    #[serde(rename = "M")]
+    pub best_match: bool,
+    #[serde(rename = "p", with = "string_or_float")]
+    pub price: f64,
+    #[serde(rename = "q", with = "string_or_float")]
+    pub qty: f64,
+}
+
 #[derive(Debug, Serialize, Deserialize, Clone)]
 pub enum MarginTransferType {
     FromMainToMargin = 1,
@@ -1160,7 +1192,7 @@ pub enum OrderStatus {
     /// The order has been accepted by the engine.
     New,
     /// A part of the order has been filled.
-    PartialyFilled,
+    PartiallyFilled,
     /// The order has been completely filled.
     Filled,
     /// The order has been canceled by the user.
@@ -1325,6 +1357,13 @@ pub struct IsolatedAccountLimit {
     pub max_account: u64,
 }
 
+#[derive(Serialize, Deserialize, Debug, Clone)]
+#[serde(rename_all = "camelCase")]
+pub struct IsolatedSymbol {
+    pub symbol: String,
+    pub max_account: u64,
+}
+
 pub mod string_or_float {
     use std::fmt;
 
